@@ -1,10 +1,11 @@
-#[cfg(target_family="unix")]
-async fn unix_main() {
-    use netscan::async_io::HostScanner;
-    use netscan::setting::{ScanType, Destination};
-    use std::time::Duration;
-    use std::net::{IpAddr, Ipv4Addr};
-    use ipnet::Ipv4Net;
+use netscan::async_io::HostScanner;
+use netscan::setting::{ScanType, Destination};
+use std::time::Duration;
+use std::net::{IpAddr, Ipv4Addr};
+use ipnet::Ipv4Net;
+use async_io;
+
+fn main() {
     let mut host_scanner = match HostScanner::new(IpAddr::V4(Ipv4Addr::new(192, 168, 1, 4))) {
         Ok(scanner) => (scanner),
         Err(e) => panic!("Error creating scanner: {}", e),
@@ -19,7 +20,9 @@ async fn unix_main() {
     host_scanner.set_scan_type(ScanType::IcmpPingScan);
     host_scanner.set_timeout(Duration::from_millis(10000));
     host_scanner.set_wait_time(Duration::from_millis(100));
-    let result = host_scanner.scan().await;
+    let result = async_io::block_on(async {
+        host_scanner.scan().await
+    });
     println!("Status: {:?}", result.scan_status);
     println!("UP Hosts:");
     for host in result.hosts {
@@ -27,16 +30,3 @@ async fn unix_main() {
     }
     println!("Scan Time: {:?}", result.scan_time);
 }
-
-#[tokio::main]
-async fn main() {
-    #[cfg(target_family="unix")]
-    {
-        unix_main().await;
-    }
-
-    #[cfg(target_family="windows")]
-    {
-        println!("Windows is not yet supported.");
-    }
-}
