@@ -1,6 +1,6 @@
 use std::net::Ipv4Addr;
-use pnet::packet::ip::{IpNextHeaderProtocol, IpNextHeaderProtocols};
-use pnet::packet::ipv4::{MutableIpv4Packet, Ipv4Flags};
+use pnet_packet::ip::{IpNextHeaderProtocol, IpNextHeaderProtocols};
+use pnet_packet::ipv4::{MutableIpv4Packet, Ipv4Flags};
 
 pub const IPV4_HEADER_LEN: usize = 20;
 
@@ -26,6 +26,6 @@ pub fn build_ipv4_packet(ipv4_packet: &mut MutableIpv4Packet, src_ip: Ipv4Addr,
         },
         _ => {},
     }
-    let checksum = pnet::packet::ipv4::checksum(&ipv4_packet.to_immutable());
+    let checksum = pnet_packet::ipv4::checksum(&ipv4_packet.to_immutable());
     ipv4_packet.set_checksum(checksum);
 }
